@@ -1,13 +1,13 @@
 #! /usr/bin/perl -w
 
-#    Copyright (C) 2004-2025 Simon Josefsson
+#    Copyright (C) 2004, 2005, 2006, 2007 Simon Josefsson
 #    Copyright (C) 1998, 1999 Tom Tromey
 #    Copyright (C) 2001 Red Hat Software
 
-# This program is free software: you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# the Free Software Foundation; either version 2, or (at your option)
+# any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,27 +15,25 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# along with this program; if not, you can either send email to this
+# program's maintainer or write to: The Free Software Foundation,
+# Inc.; 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-# I consider the output of this program to be unrestricted.  Use it as
-# you will.
-
-# Contributor(s):
+# Contributer(s):
 #   Andrew Taylor <andrew.taylor@montage.ca>
 
 # gen-unicode-tables.pl - Generate tables for libunicode from Unicode data.
 # See http://www.unicode.org/Public/UNIDATA/UnicodeCharacterDatabase.html
+# I consider the output of this program to be unrestricted.  Use it as
+# you will.
 
 # FIXME:
 # * For decomp table it might make sense to use a shift count other
 #   than 8.  We could easily compute the perfect shift count.
-# * This script no longer works with Perl 5.10.  Sigh..
 
 # we use some perl unicode features
 require 5.006;
 
-use bytes;
-
 use vars qw($CODE $NAME $CATEGORY $COMBINING_CLASSES $BIDI_CATEGORY $DECOMPOSITION $DECIMAL_VALUE $DIGIT_VALUE $NUMERIC_VALUE $MIRRORED $OLD_NAME $COMMENT $UPPER $LOWER $TITLE $BREAK_CODE $BREAK_CATEGORY $BREAK_NAME $CASE_CODE $CASE_LOWER $CASE_TITLE $CASE_UPPER $CASE_CONDITION);
 
 
@@ -171,10 +169,10 @@ elsif (@ARGV && $ARGV[0] eq '-both')
 
 if (@ARGV != 2) {
     $0 =~ s@.*/@@;
-    die "\nUsage: $0 [-decomp | -both] UNICODE-VERSION DIRECTORY\n\n       DIRECTORY should contain the following Unicode data files:\n       UnicodeData.txt, LineBreak.txt, SpecialCasing.txt, CaseFolding.txt,\n       CompositionExclusions.txt\n\n";
+    die "\nUsage: $0 [-decomp | -both] UNICODE-VERSION DIRECTORY\n\n       DIRECTORY should contain the following Unicode data files:\n       UnicodeData.txt, LineBreak.txt, SpecialCasing.txt, CaseFolding.txt,\n       CompositionExclusions.txt, BidiMirroring.txt\n\n";
 }
 
-my ($unicodedatatxt, $linebreaktxt, $specialcasingtxt, $casefoldingtxt, $compositionexclusionstxt);
+my ($unicodedatatxt, $linebreaktxt, $specialcasingtxt, $casefoldingtxt, $compositionexclusionstxt, $bidimirroringtxt);
 
 my $d = $ARGV[1];
 opendir (my $dir, $d) or die "Cannot open Unicode data dir $d: $!\n";
@@ -185,6 +183,7 @@ for my $f (readdir ($dir))
     $specialcasingtxt = "$d/$f" if ($f =~ /SpecialCasing.*\.txt/);
     $casefoldingtxt = "$d/$f" if ($f =~ /CaseFolding.*\.txt/);
     $compositionexclusionstxt = "$d/$f" if ($f =~ /CompositionExclusions.*\.txt/);
+    $bidimirroringtxt = "$d/$f" if ($f =~ /BidiMirroring.*\.txt/);
 }
 
 defined $unicodedatatxt or die "Did not find UnicodeData file";
@@ -192,11 +191,12 @@ defined $linebreaktxt or die "Did not find LineBreak file";
 defined $specialcasingtxt or die "Did not find SpecialCasing file";
 defined $casefoldingtxt or die "Did not find CaseFolding file";
 defined $compositionexclusionstxt or die "Did not find CompositionExclusions file";
+defined $bidimirroringtxt or die "Did not find BidiMirroring file";
 
 print "Creating decomp table\n" if ($do_decomp);
 print "Creating property table\n" if ($do_props);
 
-print "Composition exclusions from $compositionexclusionstxt\n";
+print "Composition exlusions from $compositionexclusionstxt\n";
 
 open (INPUT, "< $compositionexclusionstxt") || exit 1;
 
@@ -482,6 +482,23 @@ while (<INPUT>)
 
 close INPUT;
 
+open (INPUT, "< $bidimirroringtxt") || exit 1;
+
+my @bidimirror;
+while (<INPUT>)
+{
+    chomp;
+
+    next if /^#/;
+    next if /^\s*$/;
+
+    s/\s*#.*//;
+
+    @fields = split ('\s*;\s*', $_, 30);
+
+    push @bidimirror, [hex ($fields[0]), hex ($fields[1])];
+}
+ 
 if ($do_props) {
     &print_tables ($last_code)
 }
@@ -500,6 +517,7 @@ sub length_in_bytes
 {
     my ($string) = @_;
 
+    use bytes;
     return length $string;
 }
 
@@ -657,6 +675,21 @@ sub print_tables
     &output_special_case_table (\*OUT);
     &output_casefold_table (\*OUT);
 
+    print OUT "static const struct {\n";
+    print OUT "    gunichar ch;\n";
+    print OUT "    gunichar mirrored_ch;\n";
+    print OUT "} bidi_mirroring_table[] =\n";
+    print OUT "{\n";
+    $first = 1;
+    foreach $item (@bidimirror)
+    {
+        print OUT ",\n" unless $first;
+        $first = 0;
+        printf OUT "  { 0x%04x, 0x%04x }", $item->[0], $item->[1];
+        $bytes_out += 8;
+    }
+    print OUT "\n};\n\n";
+
     print OUT "#endif /* CHARTABLES_H */\n";
 
     close (OUT);
@@ -1300,3 +1333,6 @@ EOT
    my $recordlen = (2+$casefoldlen+1) & ~1;
    printf "Generated %d bytes for casefold table\n", $recordlen * @casefold;
 }
+
+			     
+
