@@ -224,7 +224,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, _("input[%lu] = U+%04x\n"),
+		fprintf (stderr, "input[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 	    }
 	  free (q);
@@ -249,7 +249,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, _("output[%lu] = U+%04x\n"),
+		fprintf (stderr, "output[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 	    }
 	  free (q);
@@ -284,7 +284,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; i < len; i++)
-		fprintf (stderr, _("input[%lu] = U+%04x\n"),
+		fprintf (stderr, "input[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 	    }
 
@@ -314,7 +314,7 @@ main (int argc, char *argv[])
 	  len = BUFSIZ;
 	  q = (uint32_t *) malloc (len * sizeof (q[0]));
 	  if (!q)
-	    error (EXIT_FAILURE, ENOMEM, _("malloc"));
+	    error (EXIT_FAILURE, ENOMEM, "malloc");
 
 	  rc = punycode_decode (strlen (readbuf), readbuf, &len, q, NULL);
 	  if (rc != PUNYCODE_SUCCESS)
@@ -328,7 +328,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; i < len; i++)
-		fprintf (stderr, _("output[%lu] = U+%04x\n"),
+		fprintf (stderr, "output[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 	    }
 
@@ -367,7 +367,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, _("input[%lu] = U+%04x\n"),
+		fprintf (stderr, "input[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 	    }
 
@@ -399,7 +399,7 @@ main (int argc, char *argv[])
 		{
 		  size_t i;
 		  for (i = 0; q[i]; i++)
-		    fprintf (stderr, _("tld[%lu] = U+%04x\n"),
+		    fprintf (stderr, "tld[%lu] = U+%04x\n",
 			     (unsigned long) i, q[i]);
 		}
 
@@ -418,7 +418,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; p[i]; i++)
-		fprintf (stderr, _("output[%lu] = U+%04x\n"),
+		fprintf (stderr, "output[%lu] = U+%04x\n",
 			 (unsigned long) i, p[i]);
 	    }
 
@@ -446,7 +446,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, _("input[%lu] = U+%04x\n"),
+		fprintf (stderr, "input[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 	    }
 	  free (q);
@@ -465,7 +465,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, _("output[%lu] = U+%04x\n"),
+		fprintf (stderr, "output[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 	    }
 
@@ -528,7 +528,7 @@ main (int argc, char *argv[])
 		}
 
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, _("input[%lu] = U+%04x\n"),
+		fprintf (stderr, "input[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 
 	      free (q);
@@ -537,7 +537,7 @@ main (int argc, char *argv[])
 	  r = stringprep_utf8_nfkc_normalize (p, -1);
 	  free (p);
 	  if (!r)
-	    error (EXIT_FAILURE, 0, _("nfkc: %s"), stringprep_strerror (rc));
+	    error (EXIT_FAILURE, 0, _("Could not do NFKC normalization."));
 
 	  if (args_info.debug_given)
 	    {
@@ -552,7 +552,7 @@ main (int argc, char *argv[])
 		}
 
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, _("output[%lu] = U+%04x\n"),
+		fprintf (stderr, "output[%lu] = U+%04x\n",
 			 (unsigned long) i, q[i]);
 
 	      free (q);
